.. include:: ../README.rst

Contents
--------

* :doc:`installation`
* :doc:`getting_started`
* :doc:`thorpe_scales`
* :doc:`shearstrain`
* :doc:`api`
* :doc:`contributing`
* :doc:`authors`
* :doc:`history`
* :doc:`zzreferences`

.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Contents:

   installation
   getting_started
   thorpe_scales
   shearstrain
   api
   contributing
   authors
   history
   zzreferences

Indices and tables
------------------
* :ref:`genindex`
* :doc:`api`

See also
--------

- `Standard Mixing Routines`_ - a repository with mixing parameterizations mostly written in Matlab.

.. _Standard Mixing Routines: https://github.com/OceanMixingCommunity/Standard-Mixing-Routines